# Changelog

<!--next-version-placeholder-->

## v1.3.1 (2023-04-21)
### Fix
* Shebang for version 3 env ([`3202092`](https://github.com/Stephen-RA-King/pizazz/commit/320209290e0782ae20229d88227989543bda2978))

### Documentation
* Update email links ([`c726e4e`](https://github.com/Stephen-RA-King/pizazz/commit/c726e4e8ae8d0fd6d449b3833cc3c3b39c0ec270))
* Rename base cookiecutter name ([`8aa5b0f`](https://github.com/Stephen-RA-King/pizazz/commit/8aa5b0f6ead9683900f453fda03506caaff69676))
* Update meta ([`656281d`](https://github.com/Stephen-RA-King/pizazz/commit/656281d2ea0b768ab88e7b58ea25364ceb133f29))
* Update email address ([`c4b94ae`](https://github.com/Stephen-RA-King/pizazz/commit/c4b94ae10a7457a4b86eda666aad1c48f766e2d2))

## v1.3.0 (2022-10-08)


## v1.2.0 (2022-10-08)
### Fix
* Add config to readthedocas.yml ([`b600dfb`](https://github.com/Stephen-RA-King/pizazz/commit/b600dfb8c33088a91e36f617a7eaa06608091b5a))

## v1.1.0 (2022-10-08)

### Fix

- Add config to readthedocas.yml ([`b600dfb`](https://github.com/Stephen-RA-King/pizazz/commit/b600dfb8c33088a91e36f617a7eaa06608091b5a))

## 1.0.2 (2022-05-22)

### First Release of 'pizazz'

<!-- Markdown link & img dfn's -->

[github](https://github.com/Stephen-RA-King/pizazz)
